pub enum TryLockError<T> {
Poisoned(PoisonError<T>),
WouldBlock,
}Expand description
Variants
Poisoned(PoisonError<T>)
The lock could not be acquired because another thread failed while holding the lock.
WouldBlock
The lock could not be acquired at this time because the operation would otherwise block.